@@ -11,19 +11,33 @@ import { Image } from "react-invenio-forms";
 import Overridable from "react-overridable";
 import { Divider, Header, Label } from "semantic-ui-react";
 import { timestampToRelativeTime } from "../utils";
-import RequestStatusIcon from "./RequestStatusIcon";
+import RequestStatus from "./RequestStatus";
+import RequestTypeLabel from "./RequestTypeLabel";
 
 const User = ({ user }) => (
-  <>
-    <Image src={user.links.avatar} avatar rounded />
+  <div className="flex">
+    <Image
+      src={user.links.avatar}
+      avatar
+      size="tiny"
+      className="mr-5"
+      ui={false}
+      rounded
+    />
     <span>{user.profile?.full_name || user.username}</span>
-  </>
+  </div>
 );
 const Community = ({ community }) => (
-  <>
-    <Image src={community.links.logo} wrapped size="mini" className="mr-5" />
+  <div className="flex">
+    <Image
+      src={community.links.logo}
+      avatar
+      size="tiny"
+      className="mr-5"
+      ui={false}
+    />
     <a href={`/communities/${community.slug}`}>{community.metadata.title}</a>
-  </>
+  </div>
 );
 
 const UserOrCommunity = ({ userData, details }) => {
@@ -32,17 +46,22 @@ const UserOrCommunity = ({ userData, details }) => {
 
   if (isUser) {
     return <User user={details} />;
-
   } else if (isCommunity) {
     return <Community community={details} />;
-
   } else {
     // default unknown created_by
     return (
-      <>
-        <Image src="/static/images/square-placeholder.png" avatar rounded />
+      <div class="flex">
+        <Image
+          src="/static/images/square-placeholder.png"
+          avatar
+          size="tiny"
+          className="mr-5"
+          ui={false}
+          rounded
+        />
         <span>{userData.user?.id || userData.community?.id}</span>
-      </>
+      </div>
     );
   }
 };
@@ -54,24 +73,39 @@ class RequestMetadata extends Component {
     return (
       <Overridable id="InvenioRequest.RequestMetadata.Layout" request={request}>
         <>
-          <Header as="h3" size="tiny">{i18next.t("Requestor")}</Header>
-          <UserOrCommunity userData={request.created_by} details={request.expanded?.created_by}/>
+          <Header as="h3" size="tiny">
+            {i18next.t("Creator")}
+          </Header>
+          <UserOrCommunity
+            userData={request.created_by}
+            details={request.expanded?.created_by}
+          />
           <Divider />
 
-          <Header as="h3" size="tiny">{i18next.t("Receiver")}</Header>
-          <UserOrCommunity userData={request.receiver} details={request.expanded?.receiver}/>
+          <Header as="h3" size="tiny">
+            {i18next.t("Receiver")}
+          </Header>
+          <UserOrCommunity
+            userData={request.receiver}
+            details={request.expanded?.receiver}
+          />
           <Divider />
 
-          <Header as="h3" size="tiny">{i18next.t("Request type")}</Header>
-          <Label>{request.type}</Label>
+          <Header as="h3" size="tiny">
+            {i18next.t("Request type")}
+          </Header>
+          <RequestTypeLabel type={request.type} />
           <Divider />
 
-          <Header as="h3" size="tiny">{i18next.t("Status")}</Header>
-          <RequestStatusIcon status={request.status} />
-          {request.status}
-          <Divider/>
+          <Header as="h3" size="tiny">
+            {i18next.t("Status")}
+          </Header>
+          <RequestStatus status={request.status} />
+          <Divider />
 
-          <Header as="h3" size="tiny">{i18next.t("Created")}</Header>
+          <Header as="h3" size="tiny">
+            {i18next.t("Created")}
+          </Header>
           {timestampToRelativeTime(request.created)}
 
           {request.expires_at && (
