@@ -5,15 +5,19 @@
 // under the terms of the MIT License; see LICENSE file for more details.
 
 import { RequestActionContext } from "@js/invenio_requests/request/actions/context";
-import { i18next } from "@translations/invenio_requests/i18next";
 import PropTypes from "prop-types";
 import React, { Component } from "react";
 import { Trans } from "react-i18next";
 import Overridable from "react-overridable";
 import { Button, Modal } from "semantic-ui-react";
 import Error from "../../components/Error";
+import { CancelButton } from "../../components/Buttons";
 
 export class RequestActionModal extends Component {
+  constructor(props){
+    super(props);
+    this.cancelBtnRef = React.createRef();
+  }
   static contextType = RequestActionContext;
 
   componentDidMount() {
@@ -29,7 +33,8 @@ export class RequestActionModal extends Component {
   };
 
   render() {
-    const { action, handleActionClick, modalId, children } = this.props;
+    const { action, handleActionClick, modalId, children, requestType } =
+      this.props;
     const { modalOpen, loading, toggleModal, error, cleanError } = this.context;
 
     const currentModalOpen = modalOpen[modalId];
@@ -41,12 +46,14 @@ export class RequestActionModal extends Component {
       >
         {/*currentModalOpen prevents mounting multiple instances*/}
         {currentModalOpen && (
-          <Modal open={currentModalOpen}>
-            <Modal.Header>
-              <Trans
-                defaults="{{action}} request"
-                values={{ action: action }}
-              />
+          <Modal role="dialog" id={modalId} open={currentModalOpen}>
+            <Modal.Header as="h2">
+              <Overridable id={`RequestActionModal.title.${action}`}>
+                <Trans
+                  defaults="{{action}} request"
+                  values={{ action: action }}
+                />
+              </Overridable>
             </Modal.Header>
             <Modal.Content>
               <Modal.Description>
@@ -55,19 +62,30 @@ export class RequestActionModal extends Component {
               </Modal.Description>
             </Modal.Content>
             <Modal.Actions>
-              <Button
+              <CancelButton
+                ref={this.cancelBtnRef}
                 onClick={() => {
                   cleanError();
                   toggleModal(modalId, false);
                 }}
                 loading={loading}
+                disabled={loading}
                 floated="left"
+                size="medium"
+              />
+              <Overridable
+                id={`RequestActionModal.button.${action}`}
+                onClick={handleActionClick}
+                loading={loading}
               >
-                {i18next.t("Cancel")}
-              </Button>
-              <Button onClick={handleActionClick} loading={loading}>
-                <Trans defaults="{{action}}" values={{ action: action }} />
-              </Button>
+                <Button
+                  onClick={handleActionClick}
+                  loading={loading}
+                  requestType={requestType}
+                >
+                  <>{action}</>
+                </Button>
+              </Overridable>
             </Modal.Actions>
           </Modal>
         )}
@@ -79,6 +97,7 @@ export class RequestActionModal extends Component {
 RequestActionModal.propTypes = {
   handleActionClick: PropTypes.func.isRequired,
   modalId: PropTypes.string.isRequired,
+  requestType: PropTypes.string.isRequired,
 };
 
 RequestActionModal.defaultProps = {
