@@ -19,7 +19,7 @@ export const RequestActions = ({ request }) => {
     >
       <>
         {actions.map((action) => (
-          <RequestAction action={action} key={action} />
+          <RequestAction action={action} key={action} requestType={request.type} />
         ))}
       </>
     </Overridable>
